pydevDAG._graphs module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »

# pydevDAG._graphs module

## pydevDAG._graphs

Tools to build graphs of various kinds.

class `pydevDAG._graphs.` `GenerateGraph`

  Bases: `object`

  Coordinate graph generating activities.

  `CONFIG` = <pydevDAG._config._Config object at 0x7fedc7c2a790>
  classmethod `decorate_graph`(graph)

    Decorate a graph with additional properties.

    Parameters: | graph (DiGraph) – the graph

  classmethod `get_graph`(context, name)

    Get a complete graph storage graph.

    Parameters: | context (Context) – the libudev context
    Returns: | the generated graph
    Return type: | DiGraph

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »